@@ -21,6 +21,10 @@ __all__ = ['init', 'ZetupCommandError', 'ZetupMakeError']
 
 import os
 
+import zetup
+
+__requires__ = zetup.__extras__['commands'].checked
+
 from path import path as Path
 
 
@@ -41,8 +45,6 @@ def init(name, path=None):
           'classifiers',
           'keywords',
           ])))
-    with open(path / 'VERSION', 'w') as f:
-        f.write("0.0.0\n")
 
 
 from . import make, run, pytest, tox, conda
